@@ -30,8 +30,13 @@ To build Maxima:
     Press carriage return to accept the default values.
 
     The configure process can be automated through the use
-    of optional arguments to configure.
-    See the file configure.lisp for details.
+    of keyword arguments to configure.  For example,
+
+      (configure :interactive nil)
+
+    will use the default values for all options and will not
+    prompt for any input.
+    See the file configure.lisp for more details.
 
 (4) Quit Lisp,
     
@@ -77,16 +82,22 @@ to subsitute their knowledge of defsystem for the following steps.
 
     That should bring up the Maxima input prompt.
 
-(9b) Dump the image, and if the Lisp implementation allows one to
-    specify a start-up function, specify USER::RUN.
+(9b) As an alternative to executing maxima immediately, most Lisps support
+    dumping the compiled application as an image that can later be loaded in
+    one piece. Often Lisp implementations additionally allow to specify a
+    start-up function that runs the application contained in the image on
+    loading it. In the case of maxima the start-up function that does this
+    is CL-USER::RUN.
 
     There is a function MAXIMA-DUMP in src/maxima-build.lisp to dump an image.
-    At present it works for Clisp, SBCL, GCL, CMUCL, Scieneer, and Allegro.
+    At present it works for Clisp, SBCL, GCL, CMUCL, Scieneer, Allegro and CCL.
     Reinhard Oldenburg writes, in reference to Lispworks:
     "(maxima-dump) works when threading is disabled."
     Some Lisp implementations (SBCL, GCL, CMUCL, Scieneer, maybe others)
     terminate after saving the image.
 
+    In order to save an image, enter the following at the Lisp input prompt:
+
     (maxima-dump)
 
 (10) Execute the saved image.
