@@ -115,7 +115,7 @@ proc openMaxima { win filter } {
 	    #puts env(MAXIMA_INT_INPUT_STRING)=$env(MAXIMA_INT_INPUT_STRING)
 	}
 	#puts com=$com
-	lappend command  $com
+	set command [concat $command  $com]
 	if { [catch $command err ] } {
 	    #mike Must return an error to stop runOneMaxima from continuing
 	    return -code error [concat [mc "Can't execute"] "$com\n$err"]
@@ -353,6 +353,8 @@ proc runOneMaxima { win } {
     global pdata
     set pdata(maxima,socket) $sock
     fileevent $sock readable  [list maximaFilter $win $sock]
+    sendMaxima $win ":lisp-quiet (setq \$maxima_frontend \"Xmaxima\")\n"
+    sendMaxima $win ":lisp-quiet (setq \$maxima_frontend_version *autoconf-version*)\n"
     return $res
 
 }
