@@ -1,13 +1,13 @@
 ;;; Compiled by f2cl version:
-;;; ("f2cl1.l,v 1.212 2009/01/08 18:58:49 rtoy Exp $"
-;;;  "f2cl2.l,v 1.37 2008/02/22 22:19:33 rtoy Exp $"
-;;;  "f2cl3.l,v 1.6 2008/02/22 22:19:33 rtoy Exp $"
-;;;  "f2cl4.l,v 1.7 2008/02/22 22:19:34 rtoy Exp $"
-;;;  "f2cl5.l,v 1.199 2009/01/07 19:16:59 rtoy Exp $"
-;;;  "f2cl6.l,v 1.48 2008/08/24 00:56:27 rtoy Exp $"
-;;;  "macros.l,v 1.112 2009/01/08 12:57:19 rtoy Exp $")
+;;; ("f2cl1.l,v 2edcbd958861 2012/05/30 03:34:52 toy $"
+;;;  "f2cl2.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl3.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl4.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl5.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $"
+;;;  "f2cl6.l,v 1d5cbacbb977 2008/08/24 00:56:27 rtoy $"
+;;;  "macros.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $")
 
-;;; Using Lisp CMU Common Lisp Snapshot 2008-12 (19E)
+;;; Using Lisp CMU Common Lisp 20d (20D Unicode)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -22,7 +22,7 @@
   (defun dtrexc (compq n t$ ldt q ldq ifst ilst work info)
     (declare (type (array double-float (*)) work q t$)
              (type (f2cl-lib:integer4) info ilst ifst ldq ldt n)
-             (type (simple-array character (*)) compq))
+             (type (simple-string *) compq))
     (f2cl-lib:with-multi-array-data
         ((compq character compq-%data% compq-%offset%)
          (t$ double-float t$-%data% t$-%offset%)
@@ -349,12 +349,11 @@
   (setf (gethash 'fortran-to-lisp::dtrexc
                  fortran-to-lisp::*f2cl-function-info*)
           (fortran-to-lisp::make-f2cl-finfo
-           :arg-types '((simple-array character (1))
-                        (fortran-to-lisp::integer4) (array double-float (*))
-                        (fortran-to-lisp::integer4) (array double-float (*))
+           :arg-types '((simple-string) (fortran-to-lisp::integer4)
+                        (array double-float (*)) (fortran-to-lisp::integer4)
+                        (array double-float (*)) (fortran-to-lisp::integer4)
                         (fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
-                        (fortran-to-lisp::integer4) (array double-float (*))
-                        (fortran-to-lisp::integer4))
+                        (array double-float (*)) (fortran-to-lisp::integer4))
            :return-values '(nil nil nil nil nil nil fortran-to-lisp::ifst
                             fortran-to-lisp::ilst nil fortran-to-lisp::info)
            :calls '(fortran-to-lisp::dlaexc fortran-to-lisp::xerbla
