@@ -33,15 +33,13 @@
 (macsyma-module askp)
 
 (declare-top (special limitp integer-info))
-   
-(defmfun $askinteger n
-  (if (or (> n 2) (< n 1)) (wna-err '$askinteger))
-  (if (= n 1) (ask-integer (arg 1) '$integer)
-      (if (member (arg 2) '($even $odd $integer) :test #'eq)
-	  (ask-integer (arg 1) (arg 2))
-	  (improper-arg-err (arg 2) '$askinteger))))
 
-(defmfun ask-integer (x even-odd)
+(defmfun $askinteger (x &optional (mode '$integer))
+  (if (member mode '($even $odd $integer) :test #'eq)
+      (ask-integer x mode)
+      (improper-arg-err mode '$askinteger)))
+
+(defun ask-integer (x even-odd)
   (setq x (sratsimp (sublis '((z** . 0) (*z* . 0)) x)))
   (cond ((ratnump x) '$no)
 	((eq even-odd '$integer) (ask-integerp x))
@@ -104,4 +102,4 @@
 		  nil))
     (cond ((member answer '($yes |$Y| |$y| |$N| |$n| $no $unknown $uk) :test #'eq)
 	   (setq end-flag t))
-	  (t (mtell "~%Acceptable answers are Yes, Y, No, N, Unknown, Uk~%")))))
+	  (t (mtell "~%Acceptable answers are: yes, y, Y, no, n, N, unknown, uk~%")))))
